Improve this Doc View Source

This service is just a simple decorator for $timeout service that adds a "flush" and "verifyNoPendingTasks" methods.

## Methods

- ###

  `flush([delay]);`

  Flushes the queue of pending tasks.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  delay (optional) | number | maximum timeout amount to flush up until

- ###

  `verifyNoPendingTasks();`

  Verifies that there are no pending tasks that need to be flushed.